@@ -1,3 +1,13 @@
+#' @title Interface to Colombos Compendia using the Exposed REST API
+#' @name Rcolombos
+#' @description Provides programmatic access to Colombos, a web based
+#'interface for exploring and analyzing comprehensive organism-specific
+#'cross-platform expression compendia of bacterial organisms.
+#' 
+#' @docType package
+#' @aliases Rcolombos Rcolombos-package
+NULL
+
 #' This method mimics the quick_search functionality of Colombos.
 #' It takes a string containg the nickname for the selected organism and a vector of string 
 #' representing the genes of interest for the specified organism and returns a list containing 
@@ -27,7 +37,7 @@
 #'
 quick_search <- function(organism="ecoli", genes, geneNames=FALSE){
     if(is.null(genes)) stop("Insert a character vector with the genes to be imputed.") else {}
-    r <- GET("http://rest.colombos.fmach.it/", path = paste("quick_search",organism, paste(genes, collapse=","), sep="/"))
+    r <- GET(getOption("REST.version"), path = paste("quick_search",organism, paste(genes, collapse=","), sep="/"))
     if (r$status_code != 200) {
         stop_for_status(r)
     } else {
@@ -135,13 +145,13 @@ advanced_search <- function(organism=NULL, g_ids=NULL, geneNames=FALSE, c_ids, b
 advanced_search_by_genes <- function(organism="bsubt", ids=NULL, geneNames=FALSE, g_search_type="genes", ann_type){
     if(is.null(ids)) stop("Insert the ids for the specific search_type.") else {}
     if(g_search_type=="genes"){
-        url_string <- paste("http://rest.colombos.fmach.it/advanced_search_by_genes", organism, "genes", paste(ids, collapse=","), sep="/")
+        url_string <- paste(getOption("REST.version"),"advanced_search_by_genes", organism, "genes", paste(ids, collapse=","), sep="/")
     }
     else if(g_search_type=="go"){
-        url_string <- paste("http://rest.colombos.fmach.it/advanced_search_by_genes", organism, "go", gsub(" ","%20", ids), sep="/")
+        url_string <- paste(getOption("REST.version"),"advanced_search_by_genes", organism, "go", gsub(" ","%20", ids), sep="/")
     }
     else if(g_search_type=="annotation"){
-        url_string <- paste("http://rest.colombos.fmach.it/advanced_search_by_genes", organism, "annotation", gsub(" ","%20", ann_type), 
+        url_string <- paste(getOption("REST.version"),"advanced_search_by_genes", organism, "annotation", gsub(" ","%20", ann_type), 
                             gsub(" ","%20", ids), sep="/")  
     } else {
         stop("Wrong search_type: it should be either genes, go or annotation!")
@@ -176,19 +186,16 @@ advanced_search_by_genes <- function(organism="bsubt", ids=NULL, geneNames=FALSE
 advanced_search_by_contrasts <- function(organism=NULL, ids=NULL, geneNames=FALSE, c_search_type=NULL){
     if(is.null(ids)) stop("Insert the ids for the specific search_type.") else {}
     if(c_search_type=="contrast_names"){
-        url_string <- paste("http://rest.colombos.fmach.it/advanced_search_by_contrast", organism, "contrast_names", paste(ids, collapse=","), sep="/")
+        url_string <- paste(getOption("REST.version"),"advanced_search_by_contrast", organism, "contrast_names", paste(ids, collapse=","), sep="/")
     }
     else if(c_search_type=="experiment"){
-        # url_string <- paste("http://rest.colombos.fmach.it/advanced_search_by_contrast", organism, "experiment", paste(gsub(" ","%20", ids), collapse=","), sep="/")
-        url_string <- paste("http://rest.colombos.fmach.it/advanced_search_by_contrast", organism, "experiment", gsub(" ","%20", ids), sep="/")
+      url_string <- paste(getOption("REST.version"),"advanced_search_by_contrast", organism, "experiment", gsub(" ","%20", ids), sep="/")
     }
     else if(c_search_type=="go"){
-        # url_string <- paste("http://rest.colombos.fmach.it/advanced_search_by_contrast", organism, "go", paste(gsub(" ","%20", ids), collapse=","), sep="/")
-        url_string <- paste("http://rest.colombos.fmach.it/advanced_search_by_contrast", organism, "go", gsub(" ","%20", ids), sep="/")
+        url_string <- paste(getOption("REST.version"),"advanced_search_by_contrast", organism, "go", gsub(" ","%20", ids), sep="/")
     }
     else if(c_search_type=="condition"){
-        # url_string <- paste("http://rest.colombos.fmach.it/advanced_search_by_contrast", organism, "condition", paste(gsub(" ","%20", ids), collapse=","), sep="/")
-        url_string <- paste("http://rest.colombos.fmach.it/advanced_search_by_contrast", organism, "condition", paste(ids, collapse=","), sep="/")
+        url_string <- paste(getOption("REST.version"),"advanced_search_by_contrast", organism, "condition", paste(ids, collapse=","), sep="/")
     } else {
         stop("Wrong search_type: it should be either contrast_names, experiment, go or condition!")
     }
@@ -225,7 +232,7 @@ advanced_search_by_contrasts <- function(organism=NULL, ids=NULL, geneNames=FALS
 advanced_search_by_both <- function(organism, g_ids, geneNames, c_ids, g_search_type, ann_type, c_search_type){
     if(is.null(g_ids)) stop("Insert a character vector with the g_ids to be imputed.") else {}
     if(is.null(c_ids)) stop("Insert a character vector with the c_ids to be imputed.") else {}
-    base_url <- "http://rest.colombos.fmach.it/advanced_search_by_both"
+    base_url <- paste(getOption("REST.version"),"advanced_search_by_both", sep="/")
     if(g_search_type=="genes"){
         g_string <- paste(base_url, organism, "genes", paste(g_ids, collapse=","), sep="/")
     }
@@ -243,15 +250,12 @@ advanced_search_by_both <- function(organism, g_ids, geneNames, c_ids, g_search_
         url_string <- paste(g_string, "contrast_names", paste(c_ids, collapse=","), sep="/")
     }
     else if(c_search_type=="experiment"){
-        # url_string <- paste(g_string, "experiment", paste(gsub(" ","%20", c_ids), collapse=","), sep="/")
         url_string <- paste(g_string, "experiment", gsub(" ","%20", c_ids), sep="/")
     }
     else if(c_search_type=="go"){
-        # url_string <- paste(g_string, "go", paste(gsub(" ","%20", c_ids), collapse=","), sep="/")
         url_string <- paste(g_string, "go", gsub(" ","%20", c_ids), sep="/")
     }
     else if(c_search_type=="condition"){
-        # url_string <- paste(g_string, "condition", paste(gsub(" ","%20", c_ids), collapse=","), sep="/")
         url_string <- paste(g_string, "condition", paste(c_ids, collapse=","), sep="/")
     } else {
         stop("Wrong search_type: it should be either contrast_names, experiment, go or condition!")
